1.5.1
=====

Refresh distribution package.

1.5
===

Allow log level to be passed on the command-line
as a numeric value as well.

1.4.1
=====

Refresh distribution package.

1.4
===

Added some nominal documentation.

Implemented automatic deploys using Travis-CI.

1.3
===

Move hosting to github.

Fix test failure due to version detection.

1.2
===

Allow passing default_level to add_arguments.

1.0
===

Initial release based on jaraco.util 10.8.
